summaryrefslogtreecommitdiff
path: root/chromium/net/http/http_server_properties_manager.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/net/http/http_server_properties_manager.h')
-rw-r--r--chromium/net/http/http_server_properties_manager.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/chromium/net/http/http_server_properties_manager.h b/chromium/net/http/http_server_properties_manager.h
index 9be5265ae9d..5412cabc947 100644
--- a/chromium/net/http/http_server_properties_manager.h
+++ b/chromium/net/http/http_server_properties_manager.h
@@ -1,4 +1,4 @@
-// Copyright 2014 The Chromium Authors. All rights reserved.
+// Copyright 2014 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -106,7 +106,7 @@ class NET_EXPORT_PRIVATE HttpServerPropertiesManager {
// by the time this method is called, calling this will prevent it from ever
// being invoked, as this method will overwrite any previous preferences.
//
// Entries associated with NetworkIsolationKeys for opaque origins are not
// written to disk.
void WriteToPrefs(
const HttpServerProperties::ServerInfoMap& server_info_map,
@@ -134,7 +134,7 @@ class NET_EXPORT_PRIVATE HttpServerPropertiesManager {
void AddServerData(const base::Value::Dict& server_dict,
HttpServerProperties::ServerInfoMap* server_info_map,
- bool use_network_isolation_key);
+ bool use_network_anonymization_key);
// Helper method used for parsing an alternative service from JSON.
// |dict| is the JSON dictionary to be parsed. It should contain fields
@@ -172,11 +172,11 @@ class NET_EXPORT_PRIVATE HttpServerPropertiesManager {
HttpServerProperties::ServerInfo* server_info);
void AddToQuicServerInfoMap(
const base::Value::Dict& server_dict,
- bool use_network_isolation_key,
+ bool use_network_anonymization_key,
HttpServerProperties::QuicServerInfoMap* quic_server_info_map);
void AddToBrokenAlternativeServices(
const base::Value::Dict& broken_alt_svc_entry_dict,
- bool use_network_isolation_key,
+ bool use_network_anonymization_key,
BrokenAlternativeServiceList* broken_alternative_service_list,
RecentlyBrokenAlternativeServices* recently_broken_alternative_services);
@@ -106,7 +106,7 @@ class NET_EXPORT_PRIVATE HttpServerPropertiesManager {
// being invoked, as this method will overwrite any previous preferences.
//
- // Entries associated with NetworkIsolationKeys for opaque origins are not
+ // Entries associated with NetworkAnonymizationKeys for opaque origins are not
// written to disk.
void WriteToPrefs(